
import heroImageUltraWebP from "@assets/hero-mobile-ultra.webp";
import heroImageMobile200AVIF from "@assets/hero-latest-mobile-200-balanced.avif";
import heroImageMobile200WebP from "@assets/hero-mobile-200.webp";
import heroImageMobile200JPG from "@assets/hero-mobile-200.jpg";
import heroImageMobile280AVIF from "@assets/hero-latest-mobile-280-opt.avif";
import heroImageDesktopAVIF from "@assets/hero-latest-desktop.avif";
import heroImage2xAVIF from "@assets/hero-latest-2x.avif";

export default function Hero() {
  const scrollToSection = (sectionId: string) => {
    console.log('Button clicked, scrolling to:', sectionId);
    
    // First try to find the element
    let element = document.getElementById(sectionId);
    
    if (element) {
      console.log('Element found, scrolling');
      element.scrollIntoView({ behavior: 'smooth' });
      return;
    }
    
    console.log('Element not found, triggering lazy load by scrolling');
    
    // Force lazy loading by scrolling to approximate position
    const sectionMap: Record<string, number> = {
      'tech-cafe': 800,
      'services': 1600,
      'problems': 2400,
      'about': 3200,
      'testimonials': 4000,
      'contact': 4800
    };
    
    const targetPosition = sectionMap[sectionId] || 0;
    
    // Scroll to approximate position to trigger intersection observer
    window.scrollTo({
      top: targetPosition,
      behavior: 'smooth'
    });
    
    // Set up observer to wait for element to appear
    let attempts = 0;
    const maxAttempts = 50;
    
    const checkForElement = () => {
      attempts++;
      element = document.getElementById(sectionId);
      
      if (element) {
        console.log('Element found after lazy load, fine-tuning scroll');
        element.scrollIntoView({ behavior: 'smooth' });
      } else if (attempts < maxAttempts) {
        setTimeout(checkForElement, 100);
      } else {
        console.log('Element still not found after maximum attempts');
      }
    };
    
    // Start checking after a brief delay
    setTimeout(checkForElement, 200);
  };



  return (
    <section className="relative bg-calibre-red py-8 lg:py-12 hero-section">
      <div className="absolute inset-0 bg-calibre-dark bg-opacity-20"></div>
      <div className="hero-grid">
        <div className="hero-content" style={{ contain: 'layout style paint', minHeight: '400px' }}>
          <h2 
            className="hero-title-responsive text-white font-bold mb-6"
            style={{
              fontFamily: 'Inter, system-ui, -apple-system, BlinkMacSystemFont, sans-serif',
              textRendering: 'optimizeSpeed',
              contain: 'layout style',
              transform: 'translateZ(0)',
              backfaceVisibility: 'hidden',
              willChange: 'auto',
              width: '100%',
              display: 'block',
              fontSize: 'clamp(2rem, 4vw, 3.5rem)',
              lineHeight: '1.2',
              wordWrap: 'break-word',
              overflowWrap: 'break-word',
              hyphens: 'auto'
            }}
          >
            Feeling Left Behind by Technology?
          </h2>
          <p className="hero-lcp-fix">
            Friendly, local tech support for remote workers, seniors, and anyone finding technology a challenge. We bridge the digital gap, simply and affordably.
          </p>
          <div className="flex flex-col sm:flex-row gap-4">
            <button 
              onClick={(e) => {
                e.preventDefault();
                e.stopPropagation();
                scrollToSection('services');
              }}
              className="bg-white text-calibre-red px-8 py-4 rounded-lg hover:bg-gray-100 transition-colors text-lg"
              style={{ 
                fontWeight: '900',
                fontFamily: 'system-ui, -apple-system, "Segoe UI", "Roboto", "Ubuntu", sans-serif',
                pointerEvents: 'auto',
                position: 'relative',
                zIndex: 20
              }}
              type="button"
            >
              <strong>Learn How We Help</strong>
            </button>
            <button 
              onClick={(e) => {
                e.preventDefault();
                e.stopPropagation();
                scrollToSection('contact');
              }}
              className="bg-white text-calibre-red px-8 py-4 rounded-lg hover:bg-gray-100 transition-colors text-lg"
              style={{ 
                fontWeight: '900',
                fontFamily: 'system-ui, -apple-system, "Segoe UI", "Roboto", "Ubuntu", sans-serif',
                pointerEvents: 'auto',
                position: 'relative',
                zIndex: 20
              }}
              type="button"
            >
              <strong>Get in Touch Today</strong>
            </button>
          </div>
        </div>
        <div className="hero-image-section relative">
          <div 
            className="hero-image-container" 
            style={{ 
              width: '100%',
              height: '0',
              paddingBottom: '60%',
              position: 'relative',
              borderRadius: '1rem',
              overflow: 'hidden',
              boxShadow: '0 25px 50px -12px rgba(0, 0, 0, 0.25)',
              contain: 'layout size style'
            }}
          >
            <div 
              className="hero-image-instant"
              style={{
                position: 'absolute',
                top: 0,
                left: 0,
                width: '100%',
                height: '100%',
                background: 'linear-gradient(135deg, #D32F2F 0%, #8B0000 100%)',
                zIndex: 1
              }}
            />
            
            <picture>
              <source 
                media="(max-width: 320px)" 
                srcSet={heroImageUltraWebP}
                sizes="150px"
                type="image/webp"
              />
              <source 
                media="(max-width: 480px)" 
                srcSet={heroImageMobile200AVIF}
                sizes="200px"
                type="image/avif"
              />
              <source 
                media="(max-width: 480px)" 
                srcSet={heroImageMobile200WebP}
                sizes="200px"
                type="image/webp"
              />
              <source 
                media="(max-width: 480px)" 
                srcSet={heroImageMobile200JPG}
                sizes="200px"
                type="image/jpeg"
              />
              <source 
                media="(min-width: 481px) and (max-width: 768px)" 
                srcSet={`${heroImageMobile280AVIF} 280w`}
                sizes="280px"
                type="image/avif"
              />
              <source 
                media="(min-width: 769px) and (max-width: 1023px)" 
                srcSet={`${heroImageDesktopAVIF} 1024w`}
                sizes="100vw"
                type="image/avif"
              />
              <source 
                media="(min-width: 1024px)" 
                srcSet={`${heroImageDesktopAVIF} 1024w, ${heroImage2xAVIF} 1200w`}
                sizes="50vw"
                type="image/avif"
              />
              <img 
                src={heroImageUltraWebP}
                alt="Professional technology support specialists helping clients with computer solutions - Calibre Tech's expert service" 
                width="150"
                height="90"
                loading="eager"
                decoding="sync"
                {...({ fetchpriority: "high" } as any)}
                data-hero="true"
                style={{
                  position: 'absolute',
                  top: 0,
                  left: 0,
                  width: '100%',
                  height: '100%',
                  objectFit: 'cover',
                  objectPosition: 'center',
                  zIndex: 2
                }}
                onLoad={(e) => {
                  const placeholder = e.currentTarget.parentElement?.querySelector('.hero-image-instant') as HTMLElement;
                  if (placeholder) {
                    placeholder.style.opacity = '0';
                  }
                }}
              />
            </picture>
          </div>
        </div>
      </div>
    </section>
  );
}